import React, { AnchorHTMLAttributes, FC, ReactNode } from 'react';
import * as atomic_router from 'atomic-router';
import { RouteParams, RouteInstance, RouteQuery, createHistoryRouter } from 'atomic-router';
import * as history from 'history';
import * as effector from 'effector';

declare type Props$1<Params extends RouteParams> = {
    to: RouteInstance<Params> | string;
    params?: Params;
    query?: RouteQuery;
    className?: string;
    activeClassName?: string;
    inactiveClassName?: string;
} & Exclude<AnchorHTMLAttributes<HTMLAnchorElement>, "href">;
declare function Link<Params extends RouteParams>({ to, params, query, className, activeClassName, inactiveClassName, ...props }: Props$1<Params>): JSX.Element;

declare type Props<Params extends RouteParams> = {
    route: RouteInstance<Params> | RouteInstance<Params>[];
    view: FC;
};
declare function Route<Params>({ route, view: Component }: Props<Params>): JSX.Element | null;

declare type Router = ReturnType<typeof createHistoryRouter>;
declare const RouterContext: React.Context<{
    $path: effector.Store<string>;
    $query: effector.Store<{}>;
    $activeRoutes: effector.Store<atomic_router.RouteInstance<any>[]>;
    $history: effector.Store<history.History>;
    setHistory: effector.Event<history.History>;
    push: effector.Effect<Omit<{
        history: history.History;
        path: string;
        params: atomic_router.RouteParams;
        query: atomic_router.RouteQuery;
        method: "replace" | "push";
    }, "history">, {
        history: history.History;
        path: string;
        params: atomic_router.RouteParams;
        query: atomic_router.RouteQuery;
        method: "replace" | "push";
    }, Error>;
    routes: {
        route: atomic_router.RouteInstance<any>;
        path: string;
    }[];
    initialized: effector.Event<{
        activeRoutes: atomic_router.RouteInstance<any>[];
        path: string;
        query: {};
    }>;
    routeNotFound: effector.Event<void>;
} | null>;
declare function RouterProvider({ router, children, }: {
    router: Router;
    children: ReactNode;
}): JSX.Element;
declare function useRouter(): {
    $path: effector.Store<string>;
    $query: effector.Store<{}>;
    $activeRoutes: effector.Store<atomic_router.RouteInstance<any>[]>;
    $history: effector.Store<history.History>;
    setHistory: effector.Event<history.History>;
    push: effector.Effect<Omit<{
        history: history.History;
        path: string;
        params: atomic_router.RouteParams;
        query: atomic_router.RouteQuery;
        method: "replace" | "push";
    }, "history">, {
        history: history.History;
        path: string;
        params: atomic_router.RouteParams;
        query: atomic_router.RouteQuery;
        method: "replace" | "push";
    }, Error>;
    routes: {
        route: atomic_router.RouteInstance<any>;
        path: string;
    }[];
    initialized: effector.Event<{
        activeRoutes: atomic_router.RouteInstance<any>[];
        path: string;
        query: {};
    }>;
    routeNotFound: effector.Event<void>;
};

declare type RouteViewConfig<Props, Params> = {
    route: RouteInstance<Params> | RouteInstance<Params>[];
    view: React.FC<Props>;
    otherwise?: React.FC<Props>;
};
declare const createRouteView: <Props, Params, Config extends {
    route?: RouteInstance<Params> | RouteInstance<Params>[] | undefined;
    view?: React.FC<Props> | undefined;
    otherwise?: React.FC<Props> | undefined;
}>(config: Config) => (props: Props & Omit<RouteViewConfig<Props, Params>, keyof Config>) => JSX.Element | null;

declare type RouteRecord<Props, Params> = {
    route: RouteInstance<Params> | RouteInstance<Params>[];
    view: FC<Props>;
};
declare type RoutesViewConfig = {
    routes: RouteRecord<unknown, unknown>[];
    otherwise?: React.FC<unknown>;
};
declare const createRoutesView: <Config extends RoutesViewConfig>(config: Config) => (props: Omit<Config, keyof Config>) => JSX.Element | null;

declare function useLink<T extends RouteParams>(route: RouteInstance<T>, params: T, query?: RouteQuery): string;

export { Link, Route, RouteViewConfig, RouterContext, RouterProvider, RoutesViewConfig, createRouteView, createRoutesView, useLink, useRouter };
